s6: the s6-fdholder-delete program
Keywords: s6 s6-fdholder fd-holding fd-holder fd delete deletion unix socket activation

s6
Software
skarnet.org

# The `s6-fdholder-delete` program

`s6-fdholder-delete` connects to a fd-holding daemon listening on a Unix domain socket, and deletes a file descriptor from the daemon storage.

## Interface

         s6-fdholder-delete [ -t timeout ] path id

- s6-fdholder-delete executes into `s6-ipcclient path s6-fdholder-deletec id` . It does nothing else: it is just a convenience program. The s6-ipcclient program connects to a Unix socket at path, and the s6-fdholder-deletec program sends instruction to the server.
- It should be used to connect to a s6-fdholderd daemon, which will receive the instruction to close and remove the file descriptor identified by id.
- It then exits 0.

## Options

- `-t timeout` : if the operation cannot be processed in timeout milliseconds, then fail with an error message. Communications with the server should be near-instant, so this option is only here to protect users against programming errors (connecting to the wrong socket, for instance).

## Usage example

       s6-fdholder-delete /service/fdholderd/s MYSOCKET

will tell a s6-fdholderd daemon listening on the `/service/fdholderd/s` socket to close the filedescriptor identified as MYSOCKET.